@@ -16,6 +16,7 @@ import logging
 import os
 import re
 import sys
+from functools import partial
 from glob import glob
 from shutil import rmtree
 
@@ -297,7 +298,6 @@ def all_(c, dry_run=False):
     prepare(c, dry_run=dry_run)
     publish(c, dry_run=dry_run)
     push(c, dry_run=dry_run)
-    tidelift(c, dry_run=dry_run)
 
 
 @task
@@ -780,7 +780,8 @@ def publish(
     # files)
     with tmpdir(skip_cleanup=dry_run, explicit=directory) as tmp:
         # Build default archives
-        build(c, sdist=sdist, wheel=wheel, directory=tmp)
+        builder = partial(build, c, sdist=sdist, wheel=wheel, directory=tmp)
+        builder()
         # Build opposing interpreter archive, if necessary
         # TODO: delete dual wheels when dropping Py2 support
         if dual_wheels:
@@ -788,7 +789,22 @@ def publish(
                 alt_python = "python2"
                 if sys.version_info[0] == 2:
                     alt_python = "python3"
-            build(c, sdist=False, wheel=True, directory=tmp, python=alt_python)
+            builder(sdist=False, wheel=True, python=alt_python)
+        # Rebuild with env (mostly for Fabric 2)
+        # TODO: code smell; implies this really wants to be class/hook based?
+        # TODO: or at least invert sometime so it's easier to say "do random
+        # stuff to arrive at dists, then test and upload".
+        rebuild_with_env = config.get("rebuild_with_env", None)
+        if rebuild_with_env:
+            old_environ = os.environ.copy()
+            os.environ.update(rebuild_with_env)
+            try:
+                builder()
+            finally:
+                os.environ.update(old_environ)
+                for key in rebuild_with_env:
+                    if key not in old_environ:
+                        del os.environ[key]
         # Use twine's check command on built artifacts (at present this just
         # validates long_description)
         print(c.config.run.echo_format.format(command="twine check"))
@@ -803,9 +819,12 @@ def publish(
 
 
 @task
-def test_install(c, directory):
+def test_install(c, directory, verbose=False):
     """
-    Test installation of build artifacts found in ``$directory/dist``.
+    Test installation of build artifacts found in ``$directory``.
+
+    Directory should either be a ``dist`` directory itself, or the parent of
+    one.
 
     Uses the `venv` module to build temporary virtualenvs.
     """
@@ -816,8 +835,17 @@ def test_install(c, directory):
         return
     import venv
 
+    # TODO: wants contextmanager or similar for only altering a setting within
+    # a given scope or block - this may pollute subsequent subroutine calls
+    if verbose:
+        old_hide = c.config.run.hide
+        c.config.run.hide = False
+
     builder = venv.EnvBuilder(with_pip=True)
-    for archive in get_archives(directory):
+    archives = get_archives(directory)
+    if not archives:
+        raise Exit("No archive files found in {}!".format(directory))
+    for archive in archives:
         # Skip Python 2 wheels that aren't universal (we're dropping that
         # entirely soon)
         if "py2" in archive and "py3" not in archive:
@@ -838,15 +866,20 @@ def test_install(c, directory):
                     pip, archive
                 )
             )
+            # TODO: install wheel and try again to make sure wheels work ok?
+
+    if verbose:
+        c.config.run.hide = old_hide
 
 
 def get_archives(directory):
     # Obtain list of archive filenames, then ensure any wheels come first
     # so their improved metadata is what PyPI sees initially (otherwise, it
     # only honors the sdist's lesser data).
+    dist = "" if directory.endswith("dist") else "dist"
     return list(
         itertools.chain.from_iterable(
-            glob(os.path.join(directory, "dist", "*.{}".format(extension)))
+            glob(os.path.join(directory, dist, "*.{}".format(extension)))
             for extension in ("whl", "tar.gz")
         )
     )
@@ -931,14 +964,6 @@ def push(c, dry_run=False):
     c.run("git push {}".format(opts), **kwargs)
 
 
-@task
-def tidelift(c, dry_run=False):
-    """
-    Add current latest version to Tidelift & set changelog link.
-    """
-    pass
-
-
 # TODO: still need time to solve the 'just myself pls' problem
 ns = Collection(
     "release",
@@ -949,7 +974,6 @@ ns = Collection(
     publish,
     push,
     test_install,
-    tidelift,
     upload,
 )
 # Hide stdout by default, preferring to explicitly enable it when necessary.
